function [H] = analytical_value_HSharmaM(distr,alpha_H,beta_H,par)
%function [H] = analytical_value_HSharmaM(distr,alpha_H,beta_H,par)
%Analytical value (H) of the Sharma-Mittal entropy for the given distribution.
%
%INPUT:
%   distr  : name of the distribution; 'normal'.
%   par    : parameters of the distribution (structure),
%            distr = 'normal': par.cov_mtx = covariance matrix.
%   alpha_H: parameter of the Sharma-Mittal entropy; alpha: >0, not 1.
%   beta_H : parameter of the Sharma-Mittal entropy; beta: not 1.

%Copyright (C) 2013 Zoltan Szabo ("http://www.gatsby.ucl.ac.uk/~szabo/", "zoltan (dot) szabo (at) gatsby (dot) ucl (dot) ac (dot) uk")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

switch distr
    case 'normal' %[Frank Nielsen and Richard Nock. A closed-form expression for the Sharma-Mittal entropy of exponential families. Journal of Physics A: Mathematical and Theoretical, 45:032003, 2012.]
        cov_mtx = par.cov_mtx;
        d = size(cov_mtx,1); %=size(cov_mtx,2)
        H = ( ( (2*pi)^(d/2) * sqrt(abs(det(cov_mtx))) )^(1-beta_H) / alpha_H^( d*(1-beta_H) / (2*(1-alpha_H)) )  - 1 ) / (1-beta_H);
    otherwise
        error('Distribution=?');                 
end
