%function [] = quick_test_Kexpected()
%Quick test for expected kernel estimators: analytical expression vs estimated value as a function of the sample number. In the test, normal variables are considered.

%Copyright (C) 2013 Zoltan Szabo ("http://www.gatsby.ucl.ac.uk/~szabo/", "zoltan (dot) szabo (at) gatsby (dot) ucl (dot) ac (dot) uk")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%clear start:
    clear all; close all;
    
%parameters:  
    distr = 'normal'; %fixed
    d = 1; %dimension of the distribution
    num_of_samples_v = [1000:1000:15*1000]; %sample numbers used for estimation
    %estimator (of the expected kernel), base:
        cost_name = 'expected';

%initialization:    
    L = length(num_of_samples_v);    
    num_of_samples_max = num_of_samples_v(end);   
    co = K_initialization(cost_name,1);
    K_hat_v = zeros(L,1); %vector of the estimated expected kernel values
    
%distr, d -> samples (Y1,Y2), analytical formula for the expected kernel:
    switch distr
        case 'normal'   
            %expectation:
                e1 = rand(d,1);
                e2 = rand(d,1);
            %(random) linear transformation applied to the data:
                A1 = rand(d);
                A2 = rand(d);
            %covariance matrix:
                cov1 = A1 * A1.';
                cov2 = A2 * A2.';
            %generate samples:
                Y1 = A1 * randn(d,num_of_samples_max) + repmat(e1,1,num_of_samples_max); %A1xN(0,I)+e1
                Y2 = A2 * randn(d,num_of_samples_max) + repmat(e2,1,num_of_samples_max); %A2xN(0,I)+e2
            %analytical value for the expected kernel:
            %Ref.:  Krikamol Muandet, Kenji Fukumizu, Francesco Dinuzzo, and Bernhard Scholkopf. Learning from distributions via support measure machines. In Advances in Neural Information Processing Systems (NIPS), pages 10-18, 2011.
                gam = 1/co.sigma^2;
                K = exp(-1/2*((e1-e2).'*inv(cov1+cov2+eye(d)/gam)*(e1-e2))) / sqrt(abs(det(gam*cov1+gam*cov2+eye(d))));
        otherwise
            error('Distribution=?');
    end 
    
%estimation:
    Tk = 0;%index of the sample number examined
    for num_of_samples = num_of_samples_v
        Tk = Tk + 1;   
        K_hat_v(Tk) = K_estimation(Y1(:,1:num_of_samples),Y2(:,1:num_of_samples),co);
        disp(strcat('Tk=',num2str(Tk),'/',num2str(L)));
    end
    
%plot:
    plot(num_of_samples_v,K_hat_v,'r',num_of_samples_v,K*ones(1,L),'g');
    legend({'estimation','analytical value'});
    xlabel('Number of samples');
    ylabel('Expected kernel');     
    
        
